@@ -2,7 +2,7 @@
 import json
 import sys
 import time
-from datetime import datetime
+from datetime import datetime,timedelta
 
 import numpy as np
 import pandas as pd
@@ -220,13 +220,18 @@ class DataAccess:
         """
         try:
             metadata = {}
+
             end_time = pd.to_datetime(end_time)
+            if IST:
+                end_time = end_time - timedelta(hours=5, minutes=30)
             end_time = int(round(end_time.timestamp()))
             if type(sensors) == list:
                 len_sensors = len(sensors)
                 if len_sensors == 0:
                     raise Exception('Message: No sensors provided')
-                n = n * len_sensors
+                if n < 1:
+                    raise ValueError('Incorrect number of data points')
+                n = int(n) * len_sensors
                 delimiter = ","
                 sensor_values = delimiter.join(sensors)
             else:
@@ -234,44 +239,39 @@ class DataAccess:
             header = {}
             cursor = {'end': end_time, 'limit': n}
             payload = {}
-            df_raw = pd.DataFrame()
-            counter =0
+            df = pd.DataFrame()
+            counter = 0
             while True:
                 for record in range(counter):
                     sys.stdout.write('\r')
                     sys.stdout.write("Approx Records Fetched %d" % (10000 * record))
                     sys.stdout.flush()
-                url = "https://" + self.url + "/api/apiLayer/getLimitedDataMultipleSensors/?device=" + device_id + "&sensor=" + sensor_values + "&eTime=" + str(cursor['end']) + "&lim=" + str(cursor['limit']) + "&cursor=true"
+                url = "https://" + self.url + "/api/apiLayer/getLimitedDataMultipleSensors/?device=" + device_id + "&sensor=" + sensor_values + "&eTime=" + str(
+                    cursor['end']) + "&lim=" + str(cursor['limit']) + "&cursor=true"
                 response = requests.request("GET", url, headers=header, data=payload)
                 raw = json.loads(response.text)
                 if response.status_code != 200:
-                    raise ValueError(raw['error'])
+                    raise ValueError(raw)
                 if 'success' in raw:
-                    raise ValueError(raw['error'])
+                    raise ValueError(raw)
                 else:
                     raw_data = json.loads(response.text)['data']
                     cursor = json.loads(response.text)['cursor']
                     if len(raw_data) != 0:
-                        df_raw = pd.concat([df_raw, pd.DataFrame(raw_data)])
+                        df = pd.concat([df, pd.DataFrame(raw_data)])
                     counter = counter + 1
                 if cursor['end'] == None:
                     break
-            if len(df_raw) != 0:
+            if len(df) != 0:
                 if IST:
-                    df_raw['time'] = pd.to_datetime(df_raw['time'], utc=False)
-                    df_raw['time'] = df_raw['time'].dt.tz_convert('Asia/Kolkata')
-                    df_raw['time'] = df_raw['time'].dt.tz_localize(None)
-                if cal == True or cal == 'true' or cal == "TRUE":
-                    df,metadata = DataAccess.get_sensor_alias(self, device_id, df_raw,metadata)
-                    df = DataAccess.get_cleaned_table(self, df)
-                    df = DataAccess.get_caliberation(self, device_id, metadata,df)
-                else:
-                    df,metadata = DataAccess.get_sensor_alias(self, device_id,df_raw,metadata)
-                    df = DataAccess.get_cleaned_table(self, df)
-            else:
-                df = df_raw
-            return df
+                    df['time'] = pd.to_datetime(df['time'], utc=False)
+                    df['time'] = df['time'].dt.tz_convert('Asia/Kolkata').dt.tz_localize(None)
+                df, metadata = DataAccess.get_sensor_alias(self, device_id, df, metadata)
+                df = DataAccess.get_cleaned_table(self, df)
 
+                if str(cal).lower() == 'true':
+                    df = DataAccess.get_caliberation(self, device_id, metadata, df)
+            return df
         except Exception as e:
             print(e)
 
@@ -287,9 +287,12 @@ class DataAccess:
         rawdata_res = []
         temp = ''
         s_time = pd.to_datetime(start_time)
-        st_time = int(round(s_time.timestamp())) * 1000000000
         e_time = pd.to_datetime(end_time)
-        en_time = int(round(e_time.timestamp())) * 1000000000
+        if IST:
+            s_time = s_time - timedelta(hours=5, minutes=30)
+            e_time = e_time - timedelta(hours=5, minutes=30)
+        st_time = int(round(s_time.timestamp())) * 10000
+        en_time = int(round(e_time.timestamp())) * 10000
         header = {}
         payload = {}
         counter = 0
@@ -324,9 +327,9 @@ class DataAccess:
             raw = json.loads(response.text)
             # print(raw)
             if response.status_code != 200:
-                raise ValueError(raw['error'])
+                raise ValueError(raw)
             if 'success' in raw:
-                raise ValueError(raw['error'])
+                raise ValueError(raw)
 
             else:
                 raw_data = json.loads(response.text)['data']
@@ -343,20 +346,18 @@ class DataAccess:
         if len(df_raw) != 0 :
             if IST:
                 df_raw['time'] = pd.to_datetime(df_raw['time'], utc=False)
-                df_raw['time'] = df_raw['time'].dt.tz_convert('Asia/Kolkata')
-                df_raw['time'] = df_raw['time'].dt.tz_localize(None)
+                df_raw['time'] = df_raw['time'].dt.tz_convert('Asia/Kolkata').dt.tz_localize(None)
+
             if len(df_raw.columns) == 2:
                 df_raw['sensor'] = sensors[0]
 
-            # print(df_raw)
+            df, metadata = DataAccess.get_sensor_alias(self, device_id, df_raw, metadata)
+            df = DataAccess.get_cleaned_table(self, df)
+
             if cal or cal == 'true' or cal == "TRUE":
                 # #qq=qq[~qq['value'].isin(['','BAD 255','BAD 0','BAD undefined','-'])]
-                df,metadata = DataAccess.get_sensor_alias(self, device_id, df_raw,metadata)
-                df = DataAccess.get_cleaned_table(self, df)
                 df = DataAccess.get_caliberation(self, device_id, metadata, df)
-            else:
-                df,metadata = DataAccess.get_sensor_alias(self, device_id, df_raw,metadata)
-                df = DataAccess.get_cleaned_table(self, df)
+
             if bands is not None:
                 df = DataAccess.time_grouping(self, df, bands)
         else:
